==> skrooge_0.2.5.orig.tar.gz: skrooge-0.2.5/skgbankmodelertest/skgtestimportstockqif.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a test script.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtestmacro.h"
#include "skgimportexportmanager.h"
#include "skgbankincludes.h"

/**
 * The main function of the unit test
 * @param argc the number of arguments
 * @param argv the list of arguments
 */
int main(int argc, char** argv)
{
        Q_UNUSED(argc);
        Q_UNUSED(argv);

        //Init test
        SKGINITTEST(true);

        QDate now=QDate::currentDate();

        {
                //Test import QIF 1
                SKGDocumentBank document1;
                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                SKGError err;
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "IMPORT_STOCK_UNIT", err);
                        SKGUnitObject unit;
                        SKGTESTERROR("QIF.createCurrencyUnit", SKGUnitObject::createCurrencyUnit(&document1, "FRF", unit), true);
                }
                document1.dump(DUMPUNIT);
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "IMPORT_STOCK_1", err);
                        SKGUnitObject unit;
                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/La Poste GMO.qif");
                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);
                        SKGImportExportManager imp2(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/La Poste GMO (Caisse).qif");
                        SKGTESTERROR("QIF.importFile", imp2.importFile(), true);
                        SKGImportExportManager imp3(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/goog.qif");
                        SKGTESTERROR("QIF.importFile", imp3.importFile(), true);
                }
                document1.dump(DUMPOPERATION|DUMPUNIT|DUMPACCOUNT);
        }

        {
                //Test import QIF -Correction bug 2307068
                SKGDocumentBank document1;
                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                SKGError err;
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "IMPORT_2307068", err);

                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/2307068-BNP CC.qif");
                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);

                        SKGImportExportManager imp12(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/2307068-Compte Titre.qif");
                        SKGTESTERROR("QIF.importFile", imp12.importFile(), true);
                }

                document1.dump(DUMPOPERATION|DUMPUNIT|DUMPACCOUNT);
                {
                        SKGAccountObject account(&document1);
                        SKGTESTERROR("QIF.setName", account.setName("2307068-Compte Titre"), true);
                        SKGTESTERROR("QIF.load", account.load(), true);
                        SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "520.0000008");
                }
        }
        //End test
        SKGENDTEST();
}

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skgbankmodelertest/skgtestimportstockqif.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a test script.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtestmacro.h"
#include "skgimportexportmanager.h"
#include "skgbankincludes.h"

/**
 * The main function of the unit test
 * @param argc the number of arguments
 * @param argv the list of arguments
 */
int main(int argc, char** argv)
{
        Q_UNUSED(argc);
        Q_UNUSED(argv);

        //Init test
        SKGINITTEST(true);

        QDate now=QDate::currentDate();

        {
                //Test import QIF 1
                SKGDocumentBank document1;
                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                SKGError err;
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "IMPORT_STOCK_UNIT", err);
                        SKGUnitObject unit;
                        SKGTESTERROR("QIF.createCurrencyUnit", SKGUnitObject::createCurrencyUnit(&document1, "FRF", unit), true);
                }
                document1.dump(DUMPUNIT);
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "IMPORT_STOCK_1", err);
                        SKGUnitObject unit;
                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/La Poste GMO.qif");
                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);
                        SKGImportExportManager imp2(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/La Poste GMO (Caisse).qif");
                        SKGTESTERROR("QIF.importFile", imp2.importFile(), true);
                        SKGImportExportManager imp3(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/goog.qif");
                        SKGTESTERROR("QIF.importFile", imp3.importFile(), true);
                }
                document1.dump(DUMPOPERATION|DUMPUNIT|DUMPACCOUNT);
        }

        {
                //Test import QIF -Correction bug 2307068
                SKGDocumentBank document1;
                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                SKGError err;
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "IMPORT_2307068", err);

                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/2307068-BNP CC.qif");
                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);

                        SKGImportExportManager imp12(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportstockqif/2307068-Compte Titre.qif");
                        SKGTESTERROR("QIF.importFile", imp12.importFile(), true);
                }

                document1.dump(DUMPOPERATION|DUMPUNIT|DUMPACCOUNT);
                {
                        SKGAccountObject account(&document1);
                        SKGTESTERROR("QIF.setName", account.setName("2307068-BNP CC"), true);
                        SKGTESTERROR("QIF.load", account.load(), true);
                        SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "-520");
                }
                {
                        SKGAccountObject account(&document1);
                        SKGTESTERROR("QIF.setName", account.setName("2307068-Compte Titre"), true);
                        SKGTESTERROR("QIF.load", account.load(), true);
                        SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "0");
                }
                {
                        SKGAccountObject account(&document1);
                        SKGTESTERROR("QIF.setName", account.setName("Compte Titre"), true);
                        SKGTESTERROR("QIF.load", account.load(), true);
                        SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "520");
                }
        }
        //End test
        SKGENDTEST();
}
